#
# spec file for package libglade2
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define _name libglade
Name:           libglade2
Version:        2.6.4
Release:        25.1
Summary:        Glade Library Compatible with the GNOME 2.x Desktop Platform
# NOTE: on upgrade to a new upstream version, change the Obsoletes from <= to < (here and in baselibs.conf)
License:        LGPL-2.1-or-later
Group:          Development/Libraries/GNOME
Url:            http://www.daa.com.au/~james/gnome/
Source:         ftp://ftp.gnome.org/pub/GNOME/sources/%{_name}/2.6/%{_name}-%{version}.tar.bz2
Source99:       baselibs.conf
# PATCH-FREATURE-OPENSUSE libglade2-python3.patch dimstar@opensuse.org -- Use python3
Patch0:         libglade2-python3.patch
BuildRequires:  fdupes
BuildRequires:  gtk2-devel
BuildRequires:  libtool
BuildRequires:  libxml2-devel
BuildRequires:  python3-base
BuildRequires:  python3-xml

%description
This library allows you to load Glade interface files in a program at
runtime. It does not require that you use Glade, but Glade is the
easiest way to create the interface files.  For an idea of how to use
the library, see the documentation, especially
%{_docdir}/libglade/test-libgladee.c and the glade-xml.h
include, which is in the libglade package.

%package -n libglade-2_0-0
Summary:        Glade Library Compatible with the GNOME 2.x Desktop Platform
Group:          Development/Libraries/GNOME
Provides:       %{name} = %{version}
# Note: we keep <= (and a rpmlint warning...) until we get a version higher than 2.6.4 (when this provides/obsoletes was introduced)
Obsoletes:      %{name} <= %{version}
#

%description -n libglade-2_0-0
This library allows you to load Glade interface files in a program at
runtime. It does not require that you use Glade, but Glade is the
easiest way to create the interface files.  For an idea of how to use
the library, see the documentation, especially
%{_docdir}/libglade/test-libgladee.c and the glade-xml.h
include, which is in the libglade package.

%package devel
Summary:        Include files and libraries mandatory for development
Group:          Development/Libraries/GNOME
Requires:       libglade-2_0-0 = %{version}
#

%description devel
This package contains all necessary include files and libraries needed
to compile and link applications that use libglade2.

%package doc
Summary:        Documentation for the Glade library
Group:          Development/Libraries/GNOME
Requires:       libglade-2_0-0 = %{version}
%if 0%{?suse_version} >= 1120
BuildArch:      noarch
%endif

%description doc
This package contains documentation and examples for the Glade library.

%prep
%setup -q -n %{_name}-%{version}
%patch0

%build
export PYTHON=%{_bindir}/python3
autoreconf -fiv
%configure --disable-static
make %{?_smp_mflags}

%install
%make_install
mkdir -p %{buildroot}%{_libdir}/libglade/2.0
find %{buildroot} -type f -name "*.la" -delete -print
%if 0%{?suse_version} > 1020
%fdupes %{buildroot}
%endif

%post -n libglade-2_0-0 -p /sbin/ldconfig
%postun -n libglade-2_0-0 -p /sbin/ldconfig

%files -n libglade-2_0-0
%license COPYING
%doc AUTHORS ChangeLog NEWS README
%{_libdir}/libglade-2.0.so.*
%dir %{_libdir}/libglade
%dir %{_libdir}/libglade/2.0

%files devel
%{_bindir}/*
%{_includedir}/libglade-2.0
%{_libdir}/libglade-2.0.so
%{_libdir}/pkgconfig/*.pc

%files doc
%{_datadir}/gtk-doc/html/libglade
%{_datadir}/xml/libglade

%changelog
* Mon Mar  5 2018 jengelh@inai.de
- Remove ineffective --with-pic.
* Wed Feb 28 2018 dimstar@opensuse.org
- Modernize spec-file by calling spec-cleaner
* Wed Nov 29 2017 dimstar@opensuse.org
- Switch to python3:
  + Add libglade2-python3.patch: convert libglade-convert to a
    python3 program.
  + Export PYTHON=/usr/bin/python3 before calling configure.
  + Replace python-devel and python-xml BuildRequires with
    python3-devel and python3-xml.
  + Add libtool BuildRequires and call to autoreconf: the currently
    bootstrapped configure script can't cope with python3 version
    comparison.
* Fri Mar  1 2013 dimstar@opensuse.org
- Spec-cleanup using format_spec_file service.
* Mon Oct 11 2010 vuntz@opensuse.org
- Update packaging to use the shared library packaging policy:
  + Create libglade-2_0-0 subpackage.
  + Add Provides/Obsoletes for libglade2 to libglade-2_0-0.
  + Update baselibs.conf accordingly.
- Remove explicit Requires of devel packages in devel subpackage:
  they will be added automatically the pkgconfig() way.
* Thu Dec 17 2009 jengelh@medozas.de
- Add baselibs.conf as a source
- Make doc subpackage a noarch package
* Tue Mar 17 2009 vuntz@novell.com
- Update to version 2.6.4:
  + Fix GTK+ single includes
  + Use G_DEFINE_TYPE instead of registering the type by hand
  + Clean up code
  + Remove deprecated GLib functions
- Remove AutoReqProv: it's default now.
- Remove unneeded BuildRequires: gnome-common, gtk-doc, indent,
  orbit2-devel, update-desktop-files.
- Do not call autoreconf.
* Wed Jan 21 2009 crrodriguez@suse.de
- remove "la" files
* Wed Jan  7 2009 olh@suse.de
- obsolete old -XXbit packages (bnc#437293)
* Thu Aug 28 2008 maw@suse.de
- Update to version 2.6.3:
  + glade_xml_new_from_buffer(): Do not call g_free() on a GObject
  + Documentation:
  * Actually show glade_xml_construct_from_buffer()
  (Murray Cumming)
  * Improve the book title and abstract
    + Mention gmodule-export-2.0 for autoconnecting (bgo#446175).
* Thu Apr 10 2008 ro@suse.de
- added baselibs.conf file to build xxbit packages
  for multilib support
* Tue Jul 31 2007 maw@suse.de
- Update to version 2.6.2, which fixes building with gtk+ 2.11
- Remove dont-disable-deprecated.patch as it is no longer needed.
* Fri Jul 27 2007 maw@suse.de
- Add dont-disable-deprecated.patch
- Use %%fdupes.
* Wed Jul 11 2007 mauro@suse.de
- Update to version 2.6.1
- Fix for bug #326511
- Added support for automake 1.10 and autoconf 2.6x
* Wed Feb  7 2007 sbrabec@suse.cz
- Do not build unusable static libraries (#238552).
* Fri Dec  8 2006 sbrabec@suse.cz
- Prefix changed to /usr.
- Spec file cleanup.
* Fri Jul 21 2006 gekker@suse.de
- Update to version 2.6.0
  - Win32 portability fixes (Tor)
  - Compiler warning fixes (Kjartan)
  - Fixes for ASCII characters in entries (Matthias)
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Mon Sep 26 2005 mls@suse.de
- make devel package require base package
* Mon Apr 11 2005 sbrabec@suse.cz
- Fixed Requires of doc subpackage.
* Mon Mar 21 2005 sbrabec@suse.cz
- Fixed Requires of devel subpackage (#61933).
* Wed Mar  2 2005 gekker@suse.de
- Update to version 2.5.1
- Note: the update below was to 2.5.0
* Thu Dec 16 2004 gekker@suse.de
- Update version
- Change aclocal to find new xml_catalog macros
* Mon Nov 22 2004 gekker@suse.de
- Update version to 2.8.0
* Thu Apr 15 2004 sbrabec@suse.cz
- Updated to version 2.3.6 (GNOME 2.6).
* Sat Jan 10 2004 adrian@suse.de
- add %%defattr and %%run_ldconfig
* Mon Jul 14 2003 sbrabec@suse.cz
- GNOME prefix change to /opt/gnome.
* Fri Jun 20 2003 sbrabec@suse.cz
- Created empty directory for libglade modules.
* Fri Jun 13 2003 sbrabec@suse.cz
- Fixed directory packaging.
- Prefix clash fix.
* Tue May 27 2003 sbrabec@suse.cz
- Clean install-root.
* Fri Oct 18 2002 sbrabec@suse.cz
- Update to version to 2.0.1.
- Clean up %%files and splitting to sub-packages.
* Fri Sep 27 2002 ro@suse.de
- Added alsa alsa-devel to neededforbuild (esound)
* Thu Aug 15 2002 hhetter@suse.de
- branch doc package
* Tue Aug 13 2002 hhetter@suse.de
- build with bonobo support (#17641)
* Fri Jun  7 2002 hhetter@suse.de
- updated to version 2.0.0
  * gtkdoc improvements
* Tue Jun  4 2002 hhetter@suse.de
- updated to version 1.99.12, source frozen
  * more changes to help with Murray's C++ bindings.
    check whether GTK has a GtkPlug implementation to help with
  * building with gtk targets other than X11.
    Only build the docs if --enable-gtk-doc is passed to configure.
  * pass CFLAGS and LDFLAGS to gtkdoc when building docs, in
    case they are needed to build against the library (fixes
    64-bit solaris issues, #81347).
  * fix up a missing g_object_ref() call in AtkRelationSet
    handling code.
  * More helpful error message if glade file could not be found
    (#80411).
* Wed May 15 2002 ro@suse.de
- use libdir
* Tue Apr  9 2002 hhetter@suse.de
- update to version 1.99.10 [gnome desktop beta3]
* Fri Feb  1 2002 hhetter@suse.de
- updated to version 1.99.6 [gnome desktop alpha2]
* Thu Jan 31 2002 ro@suse.de
- changed neededforbuild <libpng> to <libpng-devel-packages>
* Thu Jan 17 2002 hhetter@suse.de
- filelist cleanup
- prefix to /opt/gnome2
* Wed Jan 16 2002 hhetter@suse.de
- build with python-expat support
- provide libglade2-convert
* Fri Jan 11 2002 hhetter@suse.de
- build with freetype2
* Wed Jan  9 2002 hhetter@suse.de
- initial SuSE package for GNOME 2.0 platform
